@@ -1,17 +1,24 @@
 package Code::TidyAll::Plugin::CSSUnminifier;
 
-use IPC::System::Simple qw(run);
+use strict;
+use warnings;
+
 use Moo;
+
 extends 'Code::TidyAll::Plugin';
 
-our $VERSION = '0.33';
+with 'Code::TidyAll::Role::RunsCommand';
+
+our $VERSION = '0.76';
 
 sub _build_cmd {'cssunminifier'}
 
 sub transform_file {
     my ( $self, $file ) = @_;
 
-    run( $self->cmd, $self->argv, $file, $file );
+    $self->_run_or_die( $file, $file );
+
+    return;
 }
 
 1;
@@ -43,14 +50,16 @@ Install L<npm|https://npmjs.org/>, then run
 
 =head1 CONFIGURATION
 
-=over
+This plugin accepts the following configuration options:
 
-=item argv
+=head2 argv
 
-Arguments to pass to C<cssunminifier>
+Arguments to pass to C<cssunminifier>.
 
-=item cmd
+=head2 cmd
 
-Full path to C<cssunminifier>
+The path for the C<cssunminifier> command. By default this is just
+C<cssunminifier>, meaning that the user's C<PATH> will be searched for the
+command.
 
-=back
+=cut
