@@ -1,20 +1,29 @@
 package Code::TidyAll::Plugin::JSLint;
 
-use IPC::Run3 qw(run3);
+use strict;
+use warnings;
+
 use Moo;
+
 extends 'Code::TidyAll::Plugin';
 
-our $VERSION = '0.33';
+with 'Code::TidyAll::Role::RunsCommand';
+
+has '+ok_exit_codes' => (
+    default => sub { [ 0, 1 ] },
+);
+
+our $VERSION = '0.76';
 
 sub _build_cmd {'jslint'}
 
 sub validate_file {
     my ( $self, $file ) = @_;
 
-    my $cmd = sprintf( "%s %s %s", $self->cmd, $self->argv, $file );
-    my $output;
-    run3( $cmd, \undef, \$output, \$output );
-    die "$output\n" if $output !~ /is OK\./;
+    my $output = $self->_run_or_die($file);
+    die "$output\n" if $output =~ /\S/ && $output !~ /.+ is OK\./;
+
+    return;
 }
 
 1;
@@ -25,13 +34,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Code::TidyAll::Plugin::JSLint - Use jslint with tidyall
 
 =head1 VERSION
 
-version 0.33
+version 0.76
 
 =head1 SYNOPSIS
 
@@ -54,21 +65,28 @@ Install L<npm|https://npmjs.org/>, then run
 
 =head1 CONFIGURATION
 
-=over
+This plugin accepts the following configuration options:
 
-=item argv
+=head2 argv
 
-Arguments to pass to jslint
+Arguments to pass to C<jslint>.
 
-=item cmd
+=head2 cmd
 
-Full path to jslint
+The path for the C<jslint> command. By default this is just C<jslint>, meaning
+that the user's C<PATH> will be searched for the command.
 
-=back
+=head1 SUPPORT
 
-=head1 SEE ALSO
+Bugs may be submitted at
+L<https://github.com/houseabsolute/perl-code-tidyall/issues>.
 
-L<Code::TidyAll>
+I am also usually active on IRC as 'autarch' on C<irc://irc.perl.org>.
+
+=head1 SOURCE
+
+The source code repository for Code-TidyAll can be found at
+L<https://github.com/houseabsolute/perl-code-tidyall>.
 
 =head1 AUTHORS
 
@@ -86,9 +104,12 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 - 2015 by Jonathan Swartz.
+This software is copyright (c) 2011 - 2019 by Jonathan Swartz.
 
 This is free software; you can redistribute it and/or modify it under the same
 terms as the Perl 5 programming language system itself.
 
+The full text of the license can be found in the F<LICENSE> file included with
+this distribution.
+
 =cut
