@@ -4,13 +4,19 @@ use strict;
 use warnings;
 
 use JSON::MaybeXS ();
+use Specio::Library::Builtins;
+
 use Moo;
 
-our $VERSION = '0.33';
+our $VERSION = '0.76';
 
 extends 'Code::TidyAll::Plugin';
 
-has 'ascii' => ( is => 'ro', default => 0 );
+has ascii => (
+    is      => 'ro',
+    isa     => t('Bool'),
+    default => 0,
+);
 
 sub transform_source {
     my $self   = shift;
@@ -36,6 +42,8 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Code::TidyAll::Plugin::JSON - Use the JSON::MaybeXS module to tidy JSON
@@ -43,7 +51,7 @@ documents with tidyall
 
 =head1 VERSION
 
-version 0.33
+version 0.76
 
 =head1 SYNOPSIS
 
@@ -60,17 +68,23 @@ format with the keys of objects sorted.
 
 =head1 CONFIGURATION
 
-=over
+This plugin accepts the following configuration options:
 
-=item ascii
+=head2 ascii
 
 Escape non-ASCII characters. The output file will be valid ASCII.
 
-=back
+=head1 SUPPORT
 
-=head1 SEE ALSO
+Bugs may be submitted at
+L<https://github.com/houseabsolute/perl-code-tidyall/issues>.
 
-L<Code::TidyAll>
+I am also usually active on IRC as 'autarch' on C<irc://irc.perl.org>.
+
+=head1 SOURCE
+
+The source code repository for Code-TidyAll can be found at
+L<https://github.com/houseabsolute/perl-code-tidyall>.
 
 =head1 AUTHORS
 
@@ -88,9 +102,12 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 - 2015 by Jonathan Swartz.
+This software is copyright (c) 2011 - 2019 by Jonathan Swartz.
 
 This is free software; you can redistribute it and/or modify it under the same
 terms as the Perl 5 programming language system itself.
 
+The full text of the license can be found in the F<LICENSE> file included with
+this distribution.
+
 =cut
