@@ -1,20 +1,29 @@
 package Code::TidyAll::Plugin::PodTidy;
 
+use strict;
+use warnings;
+
 use Capture::Tiny qw(capture_merged);
 use Pod::Tidy;
+use Specio::Library::Numeric;
+
 use Moo;
+
 extends 'Code::TidyAll::Plugin';
 
-our $VERSION = '0.33';
+our $VERSION = '0.76';
 
-has 'columns' => ( is => 'ro' );
+has columns => (
+    is  => 'ro',
+    isa => t('PositiveInt'),
+);
 
 sub transform_file {
     my ( $self, $file ) = @_;
 
     my $output = capture_merged {
         Pod::Tidy::tidy_files(
-            files    => [$file],
+            files    => [ $file->stringify ],
             inplace  => 1,
             nobackup => 1,
             verbose  => 1,
@@ -32,13 +41,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Code::TidyAll::Plugin::PodTidy - Use podtidy with tidyall
 
 =head1 VERSION
 
-version 0.33
+version 0.76
 
 =head1 SYNOPSIS
 
@@ -60,17 +71,23 @@ Install podtidy from CPAN.
 
 =head1 CONFIGURATION
 
-=over
+This plugin accepts the following configuration options:
 
-=item columns
+=head2 columns
 
-Number of columns per line
+Number of columns per line.
 
-=back
+=head1 SUPPORT
 
-=head1 SEE ALSO
+Bugs may be submitted at
+L<https://github.com/houseabsolute/perl-code-tidyall/issues>.
 
-L<Code::TidyAll>
+I am also usually active on IRC as 'autarch' on C<irc://irc.perl.org>.
+
+=head1 SOURCE
+
+The source code repository for Code-TidyAll can be found at
+L<https://github.com/houseabsolute/perl-code-tidyall>.
 
 =head1 AUTHORS
 
@@ -88,9 +105,12 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 - 2015 by Jonathan Swartz.
+This software is copyright (c) 2011 - 2019 by Jonathan Swartz.
 
 This is free software; you can redistribute it and/or modify it under the same
 terms as the Perl 5 programming language system itself.
 
+The full text of the license can be found in the F<LICENSE> file included with
+this distribution.
+
 =cut
