@@ -1,9 +1,13 @@
 package Code::TidyAll::Plugin::SortLines;
 
+use strict;
+use warnings;
+
 use Moo;
+
 extends 'Code::TidyAll::Plugin';
 
-our $VERSION = '0.33';
+our $VERSION = '0.76';
 
 sub transform_source {
     my ( $self, $source ) = @_;
@@ -19,13 +23,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Code::TidyAll::Plugin::SortLines - Sort the lines in a file
 
 =head1 VERSION
 
-version 0.33
+version 0.76
 
 =head1 SYNOPSIS
 
@@ -40,9 +46,17 @@ Sorts the lines of a file; whitespace lines are discarded. Useful for files
 containing one entry per line, such as C<.svnignore>, C<.gitignore>, and
 C<.ispell*>.
 
-=head1 SEE ALSO
+=head1 SUPPORT
 
-L<Code::TidyAll>
+Bugs may be submitted at
+L<https://github.com/houseabsolute/perl-code-tidyall/issues>.
+
+I am also usually active on IRC as 'autarch' on C<irc://irc.perl.org>.
+
+=head1 SOURCE
+
+The source code repository for Code-TidyAll can be found at
+L<https://github.com/houseabsolute/perl-code-tidyall>.
 
 =head1 AUTHORS
 
@@ -60,9 +74,12 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 - 2015 by Jonathan Swartz.
+This software is copyright (c) 2011 - 2019 by Jonathan Swartz.
 
 This is free software; you can redistribute it and/or modify it under the same
 terms as the Perl 5 programming language system itself.
 
+The full text of the license can be found in the F<LICENSE> file included with
+this distribution.
+
 =cut
