@@ -1,23 +1,34 @@
 package Code::TidyAll::Role::Tempdir;
 
+use strict;
+use warnings;
+
+use Path::Tiny qw(tempdir);
+use Specio::Library::Builtins;
+use Specio::Library::Path::Tiny;
+
 use Moo::Role;
 
-use Cwd qw(realpath);
-use File::Temp qw(tempdir);
+our $VERSION = '0.76';
 
-our $VERSION = '0.33';
+has _tempdir => (
+    is      => 'ro',
+    isa     => t('Dir'),
+    lazy    => 1,
+    builder => 1,
+);
 
-has '_tempdir'   => ( is => 'ro', lazy => 1, builder => 1 );
-has 'no_cleanup' => ( is => 'ro', default => 0 );
+has no_cleanup => (
+    is      => 'ro',
+    isa     => t('Bool'),
+    default => 0,
+);
 
 sub _build__tempdir {
     my ($self) = @_;
-    return realpath(
-        tempdir(
-            'Code-TidyAll-XXXX',
-            TMPDIR  => 1,
-            CLEANUP => !$self->no_cleanup,
-        )
+    return tempdir(
+        'Code-TidyAll-XXXX',
+        CLEANUP => !$self->no_cleanup,
     );
 }
 
@@ -29,6 +40,8 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Code::TidyAll::Role::Tempdir - Provides a _tempdir attribute for Code::TidyAll
@@ -36,7 +49,7 @@ classes
 
 =head1 VERSION
 
-version 0.33
+version 0.76
 
 =head1 SYNOPSIS
 
@@ -48,8 +61,6 @@ version 0.33
 
 A role to add tempdir attributes to classes.
 
-=encoding UTF-8
-
 =head1 ATTRIBUTES
 
 =over
@@ -65,9 +76,17 @@ should not automatically clean up after itself
 
 =back
 
-=head1 SEE ALSO
+=head1 SUPPORT
 
-L<Code::TidyAll>
+Bugs may be submitted at
+L<https://github.com/houseabsolute/perl-code-tidyall/issues>.
+
+I am also usually active on IRC as 'autarch' on C<irc://irc.perl.org>.
+
+=head1 SOURCE
+
+The source code repository for Code-TidyAll can be found at
+L<https://github.com/houseabsolute/perl-code-tidyall>.
 
 =head1 AUTHORS
 
@@ -85,9 +104,12 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 - 2015 by Jonathan Swartz.
+This software is copyright (c) 2011 - 2019 by Jonathan Swartz.
 
 This is free software; you can redistribute it and/or modify it under the same
 terms as the Perl 5 programming language system itself.
 
+The full text of the license can be found in the F<LICENSE> file included with
+this distribution.
+
 =cut
